@@ -28,6 +28,7 @@ from pykis.client.page import KisPage
 from pykis.responses.dynamic import KisDynamic, KisList, KisObject, KisTransform
 from pykis.responses.response import KisAPIResponse, KisPaginationAPIResponse
 from pykis.responses.types import KisAny, KisDecimal, KisString
+from pykis.utils.math import safe_divide
 from pykis.utils.repr import kis_repr
 from pykis.utils.typing import Checkable
 
@@ -86,6 +87,11 @@ class KisBalanceStock(
         """매입금액"""
         ...
 
+    @property
+    def purchase_amount_krw(self) -> Decimal:
+        """매입금액(원화)"""
+        ...
+
     @property
     def current_amount(self) -> Decimal:
         """평가금액"""
@@ -259,7 +265,7 @@ class KisBalanceStockBase(KisAccountProductBase, KisOrderableAccountProductMixin
     @property
     def purchase_price(self) -> Decimal:
         """매입평균가"""
-        return self.purchase_amount / self.quantity
+        return safe_divide(self.purchase_amount, self.quantity)
 
     current_price: Decimal
     """현재가"""
@@ -301,7 +307,7 @@ class KisBalanceStockBase(KisAccountProductBase, KisOrderableAccountProductMixin
     @property
     def profit_rate(self) -> Decimal:
         """손익률 (-100 ~ 100)"""
-        return self.profit / self.purchase_amount * 100
+        return safe_divide(self.profit, self.purchase_amount) * 100
 
     @property
     def rate(self) -> Decimal:
@@ -433,7 +439,7 @@ class KisBalanceBase(KisAccountBase):
     @property
     def profit_rate(self) -> Decimal:
         """총손익률 (-100 ~ 100)"""
-        return (self.profit / self.purchase_amount * 100) if self.purchase_amount else Decimal(0)
+        return safe_divide(self.profit, self.purchase_amount) * 100
 
     @property
     def withdrawable_amount(self) -> Decimal:
@@ -516,6 +522,9 @@ class KisDomesticBalanceStock(KisDynamic, KisBalanceStockBase):
     purchase_amount: Decimal = KisDecimal["pchs_amt"]
     """매입금액"""
 
+    purchase_amount_krw: Decimal = KisDecimal["pchs_amt"]
+    """매입금액(원화)"""
+
     exchange_rate: Decimal = Decimal(1)
     """환율"""
 
@@ -623,17 +632,20 @@ class KisForeignPresentBalanceStock(KisDynamic, KisBalanceStockBase):
     current_price: Decimal = KisDecimal["ovrs_now_pric1"]
     """현재가"""
 
-    quantity: ORDER_QUANTITY = KisDecimal["cblc_qty13"]
+    quantity: ORDER_QUANTITY = KisDecimal["ccld_qty_smtl1"]
     """수량"""
     orderable: ORDER_QUANTITY = KisDecimal["ord_psbl_qty1"]
     """매도가능수량"""
 
     purchase_amount: Decimal = KisDecimal["frcr_pchs_amt"]
-    """매입금액"""
+    """매입금액(외화)"""
 
     exchange_rate: Decimal = KisDecimal["bass_exrt"]
     """환율"""
 
+    purchase_amount_krw: Decimal = KisDecimal["pchs_rmnd_wcrc_amt"]
+    """매입금액(원화)"""
+
 
 class KisForeignPresentDeposit(KisDynamic, KisDepositBase):
     """한국투자증권 해외종목 예수금"""
@@ -748,6 +760,11 @@ class KisForeignBalanceStock(KisDynamic, KisBalanceStockBase):
     purchase_amount: Decimal = KisDecimal["frcr_pchs_amt1"]
     """매입금액"""
 
+    @property
+    def purchase_amount_krw(self) -> Decimal:
+        """매입금액(원화, 당시 환율 조회 불가)"""
+        return self.purchase_amount * self.exchange_rate
+
     # Pylance bug: cached_property[Decimal] type inference error.
     @cached_property
     def exchange_rate(self) -> Decimal:  # type: ignore
@@ -1052,15 +1069,12 @@ def foreign_balance(
         ),
     )
 
-    # Issue #41 - [버그]: KisIntegrationBalance에서 해외주식 잔고수량이 0으로 표시됨
-    # https://apiportal.koreainvestment.com/apiservice/apiservice-oversea-stock-order#L_09baff2a-6e9d-4502-ba66-d7bb94094b67
-    # 위 Docs와 같이 "잔고 확인을 원하실 경우에는 해외주식 잔고[v1_해외주식-006] API 사용을 부탁드립니다.)" 라고 되어있음
-
-    result.stocks = _foreign_balance(
-        self,
-        account=account,
-        country=country,
-    ).stocks
+    if self.virtual:
+        result.stocks = _foreign_balance(
+            self,
+            account=account,
+            country=country,
+        ).stocks
 
     for stock in result.stocks:
         if isinstance(stock, KisBalanceStockBase):
